summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--client/mysqldump.c2
-rw-r--r--client/mysqltest.cc6
-rw-r--r--debian/mariadb-server-10.2.mysql.init2
-rw-r--r--debian/mariadb-server-10.2.postinst2
-rw-r--r--include/mysql.h2
-rw-r--r--libmysql/libmysql.c2
-rw-r--r--mysql-test/extra/rpl_tests/rpl_row_tabledefs.test2
-rw-r--r--mysql-test/include/mix2.inc2
-rwxr-xr-xmysql-test/lib/t/testMyConfig.t4
-rwxr-xr-xmysql-test/lib/v1/mysql-test-run.pl2
-rwxr-xr-xmysql-test/mysql-stress-test.pl2
-rwxr-xr-xmysql-test/mysql-test-run.pl6
-rw-r--r--mysql-test/r/mysqldump.result2
-rw-r--r--mysql-test/suite/engines/funcs/t/rpl_user_variables.test2
-rw-r--r--mysql-test/suite/rpl/t/rpl_user_variables.test2
-rw-r--r--mysql-test/t/greedy_optimizer.test2
-rw-r--r--mysql-test/t/mysqldump.test2
-rw-r--r--mysys/ma_dyncol.c2
-rw-r--r--plugin/auth_gssapi/README.md2
-rw-r--r--plugin/auth_pam/mapper/pam_user_map.c2
-rw-r--r--plugin/aws_key_management/CMakeLists.txt2
-rw-r--r--scripts/mysqlaccess.sh2
-rw-r--r--sql-common/client.c4
-rw-r--r--sql/handler.cc2
-rw-r--r--sql/item_func.cc2
-rw-r--r--sql/item_subselect.cc6
-rw-r--r--sql/log.cc2
-rw-r--r--sql/log_event.cc2
-rw-r--r--sql/mysqld.cc2
-rw-r--r--sql/opt_range.cc2
-rw-r--r--sql/parse_file.cc2
-rw-r--r--sql/spatial.h2
-rw-r--r--sql/sql_cache.cc10
-rw-r--r--sql/sql_class.cc4
-rw-r--r--sql/sql_db.cc2
-rw-r--r--sql/sql_select.cc2
-rw-r--r--sql/sql_show.cc2
-rw-r--r--sql/sql_table.cc2
-rw-r--r--sql/sql_yacc.yy14
-rw-r--r--sql/table.h2
-rw-r--r--storage/archive/azio.c2
-rw-r--r--storage/connect/filamdbf.cpp4
-rw-r--r--storage/connect/ha_connect.cc2
-rw-r--r--storage/connect/tabfmt.cpp2
-rw-r--r--storage/innobase/dict/dict0load.cc2
-rw-r--r--storage/innobase/row/row0merge.cc4
-rw-r--r--storage/maria/ma_bitmap.c2
-rw-r--r--storage/maria/ma_range.c2
-rw-r--r--storage/maria/maria_def.h2
-rw-r--r--storage/maria/unittest/sequence_storage.c2
-rw-r--r--storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-1.7.2.js2
-rw-r--r--storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-ui-1.8.18.custom.js2
-rw-r--r--storage/myisam/NEWS2
-rw-r--r--storage/tokudb/PerconaFT/ft/ft-flusher.cc2
-rw-r--r--storage/tokudb/PerconaFT/src/indexer-undo-do.cc2
-rw-r--r--storage/tokudb/PerconaFT/src/tests/loader-dup-test.cc2
-rwxr-xr-xstorage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure2
-rw-r--r--storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure.ac2
-rw-r--r--storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/doc/man/txt/xz.txt2
-rw-r--r--storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/main.c2
-rw-r--r--storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/xz.12
-rw-r--r--storage/tokudb/tokudb_update_fun.cc2
-rw-r--r--storage/xtradb/dict/dict0load.cc2
-rw-r--r--storage/xtradb/row/row0merge.cc4
-rw-r--r--strings/decimal.c4
-rw-r--r--strings/string.doc2
-rw-r--r--support-files/mysql.server.sh14
67 files changed, 96 insertions, 96 deletions
diff --git a/client/mysqldump.c b/client/mysqldump.c
index 1c939b87c65..febf168d2a6 100644
--- a/client/mysqldump.c
+++ b/client/mysqldump.c
@@ -6120,7 +6120,7 @@ int main(int argc, char **argv)
goto err;
/*
- No reason to explicitely COMMIT the transaction, neither to explicitely
+ No reason to explicitly COMMIT the transaction, neither to explicitly
UNLOCK TABLES: these will be automatically be done by the server when we
disconnect now. Saves some code here, some network trips, adds nothing to
server.
diff --git a/debian/mariadb-server-10.2.mysql.init b/debian/mariadb-server-10.2.mysql.init
index d5d0ab4ba93..d250ebd2e9e 100644
--- a/debian/mariadb-server-10.2.mysql.init
+++ b/debian/mariadb-server-10.2.mysql.init
@@ -25,7 +25,7 @@ SELF=$(cd $(dirname $0); pwd -P)/$(basename $0)
CONF=/etc/mysql/my.cnf
MYADMIN="/usr/bin/mysqladmin --defaults-file=/etc/mysql/debian.cnf"
-# priority can be overriden and "-s" adds output to stderr
+# priority can be overridden and "-s" adds output to stderr
ERR_LOGGER="logger -p daemon.err -t /etc/init.d/mysql -i"
# Safeguard (relative paths, core dumps..)
diff --git a/debian/mariadb-server-10.2.postinst b/debian/mariadb-server-10.2.postinst
index 83f5d5e3cd0..0244046c5a3 100644
--- a/debian/mariadb-server-10.2.postinst
+++ b/debian/mariadb-server-10.2.postinst
@@ -239,7 +239,7 @@ db_stop # in case invoke failes
# dh_systemd_start doesn't emit anything since we still ship /etc/init.d/mysql.
# Thus MariaDB server is started via init.d script, which in turn redirects to
# systemctl. If we upgrade from MySQL mysql.service may be masked, which also
-# means init.d script is disabled. Unmask mysql service explicitely.
+# means init.d script is disabled. Unmask mysql service explicitly.
# Check first that the command exists, to avoid emitting any warning messages.
if [ -x "$(command -v deb-systemd-helper)" ]; then
deb-systemd-helper unmask mysql.service > /dev/null
diff --git a/include/mysql.h b/include/mysql.h
index f088ad668a1..19099b4f404 100644
--- a/include/mysql.h
+++ b/include/mysql.h
@@ -367,7 +367,7 @@ void STDCALL mysql_server_end(void);
/*
mysql_server_init/end need to be called when using libmysqld or
libmysqlclient (exactly, mysql_server_init() is called by mysql_init() so
- you don't need to call it explicitely; but you need to call
+ you don't need to call it explicitly; but you need to call
mysql_server_end() to free memory). The names are a bit misleading
(mysql_SERVER* to be used when using libmysqlCLIENT). So we add more general
names which suit well whether you're using libmysqld or libmysqlclient. We
diff --git a/libmysql/libmysql.c b/libmysql/libmysql.c
index d5d673bb895..e91b3f75614 100644
--- a/libmysql/libmysql.c
+++ b/libmysql/libmysql.c
@@ -220,7 +220,7 @@ void STDCALL mysql_server_end()
}
#ifdef NOT_NEEDED
/*
- The following is not needed as if the program explicitely called
+ The following is not needed as if the program explicitly called
my_init() then we can assume it will also call my_end().
The reason to not also do it here is in that case we can't get
statistics from my_end() to debug log.
diff --git a/mysql-test/extra/rpl_tests/rpl_row_tabledefs.test b/mysql-test/extra/rpl_tests/rpl_row_tabledefs.test
index ddff3fa51f7..194079b160a 100644
--- a/mysql-test/extra/rpl_tests/rpl_row_tabledefs.test
+++ b/mysql-test/extra/rpl_tests/rpl_row_tabledefs.test
@@ -73,7 +73,7 @@ ALTER TABLE t8 ADD e1 INT NOT NULL DEFAULT 0, ADD e2 INT NOT NULL DEFAULT 0,
# the following INSERTs to pass the mode is switched temprorarily
set @@global.slave_exec_mode= 'IDEMPOTENT';
-# so the inserts are going to be overriden
+# so the inserts are going to be overridden
INSERT INTO t1_int VALUES (2, 4, 4711);
INSERT INTO t1_char VALUES (2, 4, 'Foo is a bar');
INSERT INTO t1_bit VALUES (2, 4, b'101', b'11100', b'01');
diff --git a/mysql-test/include/mix2.inc b/mysql-test/include/mix2.inc
index cdc39f8407f..24097514c21 100644
--- a/mysql-test/include/mix2.inc
+++ b/mysql-test/include/mix2.inc
@@ -54,7 +54,7 @@
# Set the SESSION DEFAULT STORAGE ENGINE to a value <> storage engine
# to be tested. This must not affect any CREATE TABLE statement, where
-# the storage engine is assigned explicitely,
+# the storage engine is assigned explicitly,
eval SET SESSION STORAGE_ENGINE = $other_engine_type;
#
diff --git a/mysql-test/lib/t/testMyConfig.t b/mysql-test/lib/t/testMyConfig.t
index f79e8776676..3de61af0bb9 100755
--- a/mysql-test/lib/t/testMyConfig.t
+++ b/mysql-test/lib/t/testMyConfig.t
@@ -129,10 +129,10 @@ my $config3= My::Config->new($test_include_cnf);
isa_ok( $config3, "My::Config" );
print $config3;
is( $config3->value('mysqld', 'basedir'), 'anotherbasedir',
- "mysqld_basedir has been overriden by value in test_include.cnf");
+ "mysqld_basedir has been overridden by value in test_include.cnf");
is( $config3->value('mysqld', 'option1'), 'values3',
- "mysqld_option1 has been overriden by value in test_include.cnf");
+ "mysqld_option1 has been overridden by value in test_include.cnf");
is( $config3->value('mysqld', 'option2'), 'value4',
"mysqld_option2 is from included file");
diff --git a/mysql-test/lib/v1/mysql-test-run.pl b/mysql-test/lib/v1/mysql-test-run.pl
index 79489d92742..7cf0b845745 100755
--- a/mysql-test/lib/v1/mysql-test-run.pl
+++ b/mysql-test/lib/v1/mysql-test-run.pl
@@ -4133,7 +4133,7 @@ sub valgrind_arguments {
if -f "$glob_mysql_test_dir/valgrind.supp";
}
- # Add valgrind options, can be overriden by user
+ # Add valgrind options, can be overridden by user
mtr_add_arg($args, '%s', $_) for (@valgrind_args);
mtr_add_arg($args, $$exe);
diff --git a/mysql-test/mysql-stress-test.pl b/mysql-test/mysql-stress-test.pl
index 74394e2afbd..18813c3a761 100755
--- a/mysql-test/mysql-stress-test.pl
+++ b/mysql-test/mysql-stress-test.pl
@@ -1079,7 +1079,7 @@ sub log_session_errors
{
lock ($log_file_lock);
- #header in the begining of log file
+ #header in the beginning of log file
if (!-e $stress_log_file)
{
stress_log($stress_log_file,
diff --git a/mysql-test/mysql-test-run.pl b/mysql-test/mysql-test-run.pl
index e1d50d6e0a8..c4604418ab7 100755
--- a/mysql-test/mysql-test-run.pl
+++ b/mysql-test/mysql-test-run.pl
@@ -1385,7 +1385,7 @@ sub command_line_setup {
if ( @opt_cases )
{
- # Run big tests if explicitely specified on command line
+ # Run big tests if explicitly specified on command line
$opt_big_test= 1;
}
@@ -5847,7 +5847,7 @@ sub valgrind_arguments {
}
}
- # Add valgrind options, can be overriden by user
+ # Add valgrind options, can be overridden by user
mtr_add_arg($args, '%s', $_) for (@valgrind_args);
mtr_add_arg($args, $$exe);
@@ -5874,7 +5874,7 @@ sub strace_arguments {
mtr_add_arg($args, "-f");
mtr_add_arg($args, "-o%s/var/log/%s.strace", $glob_mysql_test_dir, $mysqld_name);
- # Add strace options, can be overriden by user
+ # Add strace options, can be overridden by user
mtr_add_arg($args, '%s', $_) for (@strace_args);
mtr_add_arg($args, $$exe);
diff --git a/mysql-test/r/mysqldump.result b/mysql-test/r/mysqldump.result
index ef124e74a76..08c8c3c4d7c 100644
--- a/mysql-test/r/mysqldump.result
+++ b/mysql-test/r/mysqldump.result
@@ -514,7 +514,7 @@ drop database mysqldump_test_db;
# Check that we don't dump in UTF8 in compatible mode by default,
# but use the default compiled values, or the values given in
# --default-character-set=xxx. However, we should dump in UTF8
-# if it is explicitely set.
+# if it is explicitly set.
CREATE TABLE t1 (a CHAR(10));
INSERT INTO t1 VALUES (_latin1 'ÄÖÜß');
diff --git a/mysql-test/suite/engines/funcs/t/rpl_user_variables.test b/mysql-test/suite/engines/funcs/t/rpl_user_variables.test
index 08717fce114..530cda3d87a 100644
--- a/mysql-test/suite/engines/funcs/t/rpl_user_variables.test
+++ b/mysql-test/suite/engines/funcs/t/rpl_user_variables.test
@@ -35,7 +35,7 @@ insert into t1 values (@i1), (@i2), (@i3), (@i4);
insert into t1 values (@r1), (@r2);
insert into t1 values (@s1), (@s2), (@s3), (@s4), (@s5);
insert into t1 values (@n1);
-insert into t1 values (@n2); # not explicitely set before
+insert into t1 values (@n2); # not explicitly set before
insert into t1 values (@a:=0), (@a:=@a+1), (@a:=@a+1);
insert into t1 values (@a+(@b:=@a+1));
set @q:='abc';
diff --git a/mysql-test/suite/rpl/t/rpl_user_variables.test b/mysql-test/suite/rpl/t/rpl_user_variables.test
index 3edd9b0a5bf..08d9b4aee16 100644
--- a/mysql-test/suite/rpl/t/rpl_user_variables.test
+++ b/mysql-test/suite/rpl/t/rpl_user_variables.test
@@ -38,7 +38,7 @@ insert into t1 values (@i1), (@i2), (@i3), (@i4);
insert into t1 values (@r1), (@r2);
insert into t1 values (@s1), (@s2), (@s3), (@s4), (@s5);
insert into t1 values (@n1);
-insert into t1 values (@n2); # not explicitely set before
+insert into t1 values (@n2); # not explicitly set before
insert into t1 values (@a:=0), (@a:=@a+1), (@a:=@a+1);
insert into t1 values (@a+(@b:=@a+1));
set @q:='abc';
diff --git a/mysql-test/t/greedy_optimizer.test b/mysql-test/t/greedy_optimizer.test
index 8f969f2562a..dcd0587d76e 100644
--- a/mysql-test/t/greedy_optimizer.test
+++ b/mysql-test/t/greedy_optimizer.test
@@ -138,7 +138,7 @@ insert into t7 values (21,2,3,4,5,6);
# The actual test begins here
#
-# Check the default values for the optimizer paramters
+# Check the default values for the optimizer parameters
select @@optimizer_search_depth;
select @@optimizer_prune_level;
diff --git a/mysql-test/t/mysqldump.test b/mysql-test/t/mysqldump.test
index 9cde1f93a4a..ccc68485bd6 100644
--- a/mysql-test/t/mysqldump.test
+++ b/mysql-test/t/mysqldump.test
@@ -174,7 +174,7 @@ drop database mysqldump_test_db;
--echo # Check that we don't dump in UTF8 in compatible mode by default,
--echo # but use the default compiled values, or the values given in
--echo # --default-character-set=xxx. However, we should dump in UTF8
---echo # if it is explicitely set.
+--echo # if it is explicitly set.
CREATE TABLE t1 (a CHAR(10));
INSERT INTO t1 VALUES (_latin1 'ÄÖÜß');
diff --git a/mysys/ma_dyncol.c b/mysys/ma_dyncol.c
index 92418e38c2e..db7d199bcd2 100644
--- a/mysys/ma_dyncol.c
+++ b/mysys/ma_dyncol.c
@@ -2066,7 +2066,7 @@ static uchar *find_entry_named(DYN_HEADER *hdr, LEX_STRING *key)
/**
Write number in the buffer (backward direction - starts from the buffer end)
- @return pointer on the number begining
+ @return pointer on the number beginning
*/
static char *backwritenum(char *chr, uint numkey)
diff --git a/plugin/auth_gssapi/README.md b/plugin/auth_gssapi/README.md
index 7f678400f0d..b2c17353fc5 100644
--- a/plugin/auth_gssapi/README.md
+++ b/plugin/auth_gssapi/README.md
@@ -124,6 +124,6 @@ Send resulting GSSAPI blob to server.
3. Server : receive blob from client, execute ```gss_accept_sec_context()/ AcceptSecurityContext()```, send resulting blob back to client
-4. Perform 2. and 3. can until both client and server decide that authentication is done, or until some error occured. If authentication was successful, GSSAPI context (an opaque structure) is generated on both client and server sides.
+4. Perform 2. and 3. can until both client and server decide that authentication is done, or until some error occurred. If authentication was successful, GSSAPI context (an opaque structure) is generated on both client and server sides.
5. Server : Client name is extracted from the context, and compared to the name provided by client(with or without realm). If name matches, plugin returns success.
diff --git a/plugin/auth_pam/mapper/pam_user_map.c b/plugin/auth_pam/mapper/pam_user_map.c
index fb149c5cc05..2d20d3b4b1d 100644
--- a/plugin/auth_pam/mapper/pam_user_map.c
+++ b/plugin/auth_pam/mapper/pam_user_map.c
@@ -15,7 +15,7 @@ auth required pam_user_map.so
in the format: orig_user_name: mapped_user_name
@user's_group_name: mapped_user_name
=========================================================
-#comments and emtpy lines are ignored
+#comments and empty lines are ignored
john: jack
bob: admin
top: accounting
diff --git a/plugin/aws_key_management/CMakeLists.txt b/plugin/aws_key_management/CMakeLists.txt
index 97bcfbb04db..e414b9e6ad8 100644
--- a/plugin/aws_key_management/CMakeLists.txt
+++ b/plugin/aws_key_management/CMakeLists.txt
@@ -10,7 +10,7 @@
# Give message why the building this plugin is skipped (only if -DVERBOSE is defined)
-# or if plugin is explicitely requested to build. Then bail out.
+# or if plugin is explicitly requested to build. Then bail out.
MACRO(SKIP_AWS_PLUGIN msg)
IF(VERBOSE OR "${PLUGIN_AWS_KEY_MANAGEMENT}" MATCHES "^(STATIC|DYNAMIC)$")
MESSAGE(STATUS "Skip aws_key_management - ${msg}")
diff --git a/scripts/mysqlaccess.sh b/scripts/mysqlaccess.sh
index a7cc2eccf38..59d1bded245 100644
--- a/scripts/mysqlaccess.sh
+++ b/scripts/mysqlaccess.sh
@@ -262,7 +262,7 @@ Release Notes:
* default values are read from a configuration file $script.conf
first this file is looked for in the current directory; if not
found it is looked for in @sysconfdir@
- Note that when default-values are given, these can't get overriden
+ Note that when default-values are given, these can't get overridden
by empty (blanc) values!
* CGI-BIN version with HTML and forms interface. Simply place the
script in an ScriptAliased directory, make the configuration file
diff --git a/sql-common/client.c b/sql-common/client.c
index b96231fcc13..be17e3e72db 100644
--- a/sql-common/client.c
+++ b/sql-common/client.c
@@ -1626,10 +1626,10 @@ mysql_init(MYSQL *mysql)
How this change impacts existing apps:
- existing apps which relyed on the default will see a behaviour change;
they will have to set reconnect=1 after mysql_real_connect().
- - existing apps which explicitely asked for reconnection (the only way they
+ - existing apps which explicitly asked for reconnection (the only way they
could do it was by setting mysql.reconnect to 1 after mysql_real_connect())
will not see a behaviour change.
- - existing apps which explicitely asked for no reconnection
+ - existing apps which explicitly asked for no reconnection
(mysql.reconnect=0) will not see a behaviour change.
*/
mysql->reconnect= 0;
diff --git a/sql/handler.cc b/sql/handler.cc
index f8683c54242..de8a29f9c1e 100644
--- a/sql/handler.cc
+++ b/sql/handler.cc
@@ -2826,7 +2826,7 @@ void handler::adjust_next_insert_id_after_explicit_value(ulonglong nr)
{
/*
If we have set THD::next_insert_id previously and plan to insert an
- explicitely-specified value larger than this, we need to increase
+ explicitly-specified value larger than this, we need to increase
THD::next_insert_id to be greater than the explicit value.
*/
if ((next_insert_id > 0) && (nr >= next_insert_id))
diff --git a/sql/item_func.cc b/sql/item_func.cc
index 57bd004cf88..c6a3459848e 100644
--- a/sql/item_func.cc
+++ b/sql/item_func.cc
@@ -4903,7 +4903,7 @@ Item_func_set_user_var::update_hash(void *ptr, uint length,
bool unsigned_arg)
{
/*
- If we set a variable explicitely to NULL then keep the old
+ If we set a variable explicitly to NULL then keep the old
result type of the variable
*/
if (args[0]->type() == Item::FIELD_ITEM)
diff --git a/sql/item_subselect.cc b/sql/item_subselect.cc
index 94e7bc98618..7291f0a5b3f 100644
--- a/sql/item_subselect.cc
+++ b/sql/item_subselect.cc
@@ -2212,7 +2212,7 @@ Item_in_subselect::row_value_transformer(JOIN *join)
/*
The uncacheable property controls a number of actions, e.g. whether to
save/restore (via init_save_join_tab/restore_tmp) the original JOIN for
- plans with a temp table where the original JOIN was overriden by
+ plans with a temp table where the original JOIN was overridden by
make_simple_join. The UNCACHEABLE_EXPLAIN is ignored by EXPLAIN, thus
non-correlated subqueries will not appear as such to EXPLAIN.
*/
@@ -2508,7 +2508,7 @@ bool Item_in_subselect::create_in_to_exists_cond(JOIN *join_arg)
/*
The uncacheable property controls a number of actions, e.g. whether to
save/restore (via init_save_join_tab/restore_tmp) the original JOIN for
- plans with a temp table where the original JOIN was overriden by
+ plans with a temp table where the original JOIN was overridden by
make_simple_join. The UNCACHEABLE_EXPLAIN is ignored by EXPLAIN, thus
non-correlated subqueries will not appear as such to EXPLAIN.
*/
@@ -4622,7 +4622,7 @@ subselect_hash_sj_engine::choose_partial_match_strategy(
/*
Choose according to global optimizer switch. If only one of the switches is
'ON', then the remaining strategy is the only possible one. The only cases
- when this will be overriden is when the total size of all buffers for the
+ when this will be overridden is when the total size of all buffers for the
merge strategy is bigger than the 'rowid_merge_buff_size' system variable,
or if there isn't enough physical memory to allocate the buffers.
*/
diff --git a/sql/log.cc b/sql/log.cc
index c81869a57e7..d230b1ceb0d 100644
--- a/sql/log.cc
+++ b/sql/log.cc
@@ -4372,7 +4372,7 @@ int MYSQL_BIN_LOG::purge_first_log(Relay_log_info* rli, bool included)
/*
* Need to update the log pos because purge logs has been called
- * after fetching initially the log pos at the begining of the method.
+ * after fetching initially the log pos at the beginning of the method.
*/
if((error=find_log_pos(&rli->linfo, rli->event_relay_log_name, 0)))
{
diff --git a/sql/log_event.cc b/sql/log_event.cc
index f7e718fccd0..492c83c9e96 100644
--- a/sql/log_event.cc
+++ b/sql/log_event.cc
@@ -8017,7 +8017,7 @@ void User_var_log_event::print(FILE* file, PRINT_EVENT_INFO* print_event_info)
return;
str_to_hex(hex_str, val, val_len);
/*
- For proper behaviour when mysqlbinlog|mysql, we need to explicitely
+ For proper behaviour when mysqlbinlog|mysql, we need to explicitly
specify the variable's collation. It will however cause problems when
people want to mysqlbinlog|mysql into another server not supporting the
character set. But there's not much to do about this and it's unlikely.
diff --git a/sql/mysqld.cc b/sql/mysqld.cc
index 0e3b474f5fb..5d7c6ef9b2f 100644
--- a/sql/mysqld.cc
+++ b/sql/mysqld.cc
@@ -7200,7 +7200,7 @@ struct my_option my_long_options[]=
GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0},
/*
Because Sys_var_bit does not support command-line options, we need to
- explicitely add one for --autocommit
+ explicitly add one for --autocommit
*/
{"autocommit", 0, "Set default value for autocommit (0 or 1)",
&opt_autocommit, &opt_autocommit, 0,
diff --git a/sql/opt_range.cc b/sql/opt_range.cc
index a69709bbf03..9cf6c1d5eab 100644
--- a/sql/opt_range.cc
+++ b/sql/opt_range.cc
@@ -13914,7 +13914,7 @@ int QUICK_GROUP_MIN_MAX_SELECT::next_max()
SELECT [SUM|COUNT|AVG](DISTINCT a,...) FROM t
This method comes to replace the index scan + Unique class
(distinct selection) for loose index scan that visits all the rows of a
- covering index instead of jumping in the begining of each group.
+ covering index instead of jumping in the beginning of each group.
TODO: Placeholder function. To be replaced by a handler API call
@param is_index_scan hint to use index scan instead of random index read
diff --git a/sql/parse_file.cc b/sql/parse_file.cc
index f3dab4f7b2f..1cd294c1c7a 100644
--- a/sql/parse_file.cc
+++ b/sql/parse_file.cc
@@ -660,7 +660,7 @@ parse_quoted_escaped_string(const char *ptr, const char *end,
@param[in,out] ptr pointer to parameter
@param[in] end end of the configuration
- @param[in] line pointer to the line begining
+ @param[in] line pointer to the line beginning
@param[in] base base address for parameter writing (structure
like TABLE)
@param[in] parameter description
diff --git a/sql/spatial.h b/sql/spatial.h
index 6f50acac984..2e449844d47 100644
--- a/sql/spatial.h
+++ b/sql/spatial.h
@@ -352,7 +352,7 @@ protected:
Need to perform the calculation in logical units, since multiplication
can overflow the size data type.
- @arg data pointer to the begining of the points array
+ @arg data pointer to the beginning of the points array
@arg expected_points number of points expected
@arg extra_point_space extra space for each point element in the array
@return true if there are not enough points
diff --git a/sql/sql_class.cc b/sql/sql_class.cc
index ccb26e5a713..0f9afb9c253 100644
--- a/sql/sql_class.cc
+++ b/sql/sql_class.cc
@@ -1783,7 +1783,7 @@ THD::~THD()
NOTES
This function assumes that all variables at start are long/ulong and
- other types are handled explicitely
+ other types are handled explicitly
*/
void add_to_status(STATUS_VAR *to_var, STATUS_VAR *from_var)
@@ -1832,7 +1832,7 @@ void add_to_status(STATUS_VAR *to_var, STATUS_VAR *from_var)
NOTE
This function assumes that all variables at start are long/ulong and
- other types are handled explicitely
+ other types are handled explicitly
*/
void add_diff_to_status(STATUS_VAR *to_var, STATUS_VAR *from_var,
diff --git a/sql/sql_db.cc b/sql/sql_db.cc
index be835e45ec7..1a0ee03ec34 100644
--- a/sql/sql_db.cc
+++ b/sql/sql_db.cc
@@ -1778,7 +1778,7 @@ bool mysql_upgrade_db(THD *thd, LEX_STRING *old_db)
create trigger trg1 before insert on t2 for each row set @a:=1
rename database d1 to d2;
- TODO: Triggers, having the renamed database explicitely written
+ TODO: Triggers, having the renamed database explicitly written
in the table qualifiers.
1. when the same database is renamed:
create trigger d1.trg1 before insert on d1.t1 for each row set @a:=1;
diff --git a/sql/sql_select.cc b/sql/sql_select.cc
index 77a7f8d6c50..61755817b6d 100644
--- a/sql/sql_select.cc
+++ b/sql/sql_select.cc
@@ -2033,7 +2033,7 @@ JOIN::optimize_inner()
}
}
}
- else if (order && // ORDER BY wo/ preceeding GROUP BY
+ else if (order && // ORDER BY wo/ preceding GROUP BY
(simple_order || skip_sort_order)) // which is possibly skippable
{
if (test_if_skip_sort_order(tab, order, select_limit, false,
diff --git a/sql/sql_show.cc b/sql/sql_show.cc
index 923114ae0d4..ba9977f65b1 100644
--- a/sql/sql_show.cc
+++ b/sql/sql_show.cc
@@ -2624,7 +2624,7 @@ int select_result_explain_buffer::send_data(List<Item> &items)
DBUG_ENTER("select_result_explain_buffer::send_data");
/*
- Switch to the recieveing thread, so that we correctly count memory used
+ Switch to the receiveing thread, so that we correctly count memory used
by it. This is needed as it's the receiving thread that will free the
memory.
*/
diff --git a/sql/sql_table.cc b/sql/sql_table.cc
index 0be329e76c2..60bfe7cd1aa 100644
--- a/sql/sql_table.cc
+++ b/sql/sql_table.cc
@@ -4220,7 +4220,7 @@ bool validate_comment_length(THD *thd, LEX_STRING *comment, size_t max_len,
create_info Table create information
DESCRIPTION
- If the table character set was not given explicitely,
+ If the table character set was not given explicitly,
let's fetch the database default character set and
apply it to the table.
*/
diff --git a/sql/sql_yacc.yy b/sql/sql_yacc.yy
index be426ad7c43..7ab11716f93 100644
--- a/sql/sql_yacc.yy
+++ b/sql/sql_yacc.yy
@@ -2451,9 +2451,9 @@ master_file_def:
If the user specified a value < BIN_LOG_HEADER_SIZE, adjust it
instead of causing subsequent errors.
We need to do it in this file, because only there we know that
- MASTER_LOG_POS has been explicitely specified. On the contrary
+ MASTER_LOG_POS has been explicitly specified. On the contrary
in change_master() (sql_repl.cc) we cannot distinguish between 0
- (MASTER_LOG_POS explicitely specified as 0) and 0 (unspecified),
+ (MASTER_LOG_POS explicitly specified as 0) and 0 (unspecified),
whereas we want to distinguish (specified 0 means "read the binlog
from 0" (4 in fact), unspecified means "don't change the position
(keep the preceding value)").
@@ -8097,7 +8097,7 @@ checksum:
{
LEX *lex=Lex;
lex->sql_command = SQLCOM_CHECKSUM;
- /* Will be overriden during execution. */
+ /* Will be overridden during execution. */
YYPS->m_lock_type= TL_UNLOCK;
}
table_list opt_checksum_type
@@ -8123,7 +8123,7 @@ repair:
lex->no_write_to_binlog= $2;
lex->check_opt.init();
lex->alter_info.reset();
- /* Will be overriden during execution. */
+ /* Will be overridden during execution. */
YYPS->m_lock_type= TL_UNLOCK;
}
repair_table_or_view
@@ -8165,7 +8165,7 @@ analyze:
lex->no_write_to_binlog= $2;
lex->check_opt.init();
lex->alter_info.reset();
- /* Will be overriden during execution. */
+ /* Will be overridden during execution. */
YYPS->m_lock_type= TL_UNLOCK;
}
analyze_table_list
@@ -8287,7 +8287,7 @@ check: CHECK_SYM
lex->sql_command = SQLCOM_CHECK;
lex->check_opt.init();
lex->alter_info.reset();
- /* Will be overriden during execution. */
+ /* Will be overridden during execution. */
YYPS->m_lock_type= TL_UNLOCK;
}
check_view_or_table
@@ -8337,7 +8337,7 @@ optimize:
lex->no_write_to_binlog= $2;
lex->check_opt.init();
lex->alter_info.reset();
- /* Will be overriden during execution. */
+ /* Will be overridden during execution. */
YYPS->m_lock_type= TL_UNLOCK;
}
table_list
diff --git a/sql/table.h b/sql/table.h
index c207588a049..08e823716eb 100644
--- a/sql/table.h
+++ b/sql/table.h
@@ -968,7 +968,7 @@ public:
@param length string length
@retval Pointer to the copied string.
- @retval 0 if an error occured.
+ @retval 0 if an error occurred.
*/
char *store(const char *from, uint length)
{
diff --git a/storage/archive/azio.c b/storage/archive/azio.c
index c1efe19e91f..cc2140e838e 100644
--- a/storage/archive/azio.c
+++ b/storage/archive/azio.c
@@ -220,7 +220,7 @@ int write_header(azio_stream *s)
AZHEADER_SIZE + AZMETA_BUFFER_SIZE); /* FRM position */
*(ptr + AZ_DIRTY_POS)= (unsigned char)s->dirty; /* Start of Data Block Index Block */
- /* Always begin at the begining, and end there as well */
+ /* Always begin at the beginning, and end there as well */
return my_pwrite(s->file, (uchar*) buffer, AZHEADER_SIZE + AZMETA_BUFFER_SIZE,
0, MYF(MY_NABP)) ? 1 : 0;
}
diff --git a/storage/connect/filamdbf.cpp b/storage/connect/filamdbf.cpp
index 8afda723578..327bcf376df 100644
--- a/storage/connect/filamdbf.cpp
+++ b/storage/connect/filamdbf.cpp
@@ -655,7 +655,7 @@ bool DBFFAM::AllocateBuffer(PGLOBAL g)
} // endif Headlen
/**************************************************************************/
- /* Position the file at the begining of the data. */
+ /* Position the file at the beginning of the data. */
/**************************************************************************/
if (Tdbp->GetMode() == MODE_INSERT)
rc = fseek(Stream, 0, SEEK_END);
@@ -969,7 +969,7 @@ bool DBMFAM::AllocateBuffer(PGLOBAL g)
} // endif Headlen
/**************************************************************************/
- /* Position the file at the begining of the data. */
+ /* Position the file at the beginning of the data. */
/**************************************************************************/
Fpos = Mempos = Memory + Headlen;
Top--; // Because of EOF marker
diff --git a/storage/connect/ha_connect.cc b/storage/connect/ha_connect.cc
index d96d7455d8b..7fda7d86ece 100644
--- a/storage/connect/ha_connect.cc
+++ b/storage/connect/ha_connect.cc
@@ -3359,7 +3359,7 @@ int ha_connect::delete_row(const uchar *)
/****************************************************************************/
-/* We seem to come here at the begining of an index use. */
+/* We seem to come here at the beginning of an index use. */
/****************************************************************************/
int ha_connect::index_init(uint idx, bool sorted)
{
diff --git a/storage/connect/tabfmt.cpp b/storage/connect/tabfmt.cpp
index 015f8d93b15..b786fb64b56 100644
--- a/storage/connect/tabfmt.cpp
+++ b/storage/connect/tabfmt.cpp
@@ -964,7 +964,7 @@ bool TDBCSV::PrepareWriting(PGLOBAL g)
if (!strlen(Field[i])) {
// Generally null fields are not quoted
if (Quoted > 2)
- // Except if explicitely required
+ // Except if explicitly required
strcat(strcat(To_Line, qot), qot);
} else if (Qot && (strchr(Field[i], Sep) || *Field[i] == Qot
diff --git a/storage/innobase/dict/dict0load.cc b/storage/innobase/dict/dict0load.cc
index d8bd0a66ade..2518ba68afd 100644
--- a/storage/innobase/dict/dict0load.cc
+++ b/storage/innobase/dict/dict0load.cc
@@ -488,7 +488,7 @@ err_len:
return("incorrect column length in SYS_FOREIGN");
}
- /* This recieves a dict_foreign_t* that points to a stack variable.
+ /* This receives a dict_foreign_t* that points to a stack variable.
So mem_heap_free(foreign->heap) is not used as elsewhere.
Since the heap used here is freed elsewhere, foreign->heap
is not assigned. */
diff --git a/storage/innobase/row/row0merge.cc b/storage/innobase/row/row0merge.cc
index 294facf9723..36ae979e965 100644
--- a/storage/innobase/row/row0merge.cc
+++ b/storage/innobase/row/row0merge.cc
@@ -97,7 +97,7 @@ row_merge_encrypt_buf(
key_version = encryption_key_get_latest_version(crypt_data->key_id);
- /* Store key_version at the begining of the input buffer */
+ /* Store key_version at the beginning of the input buffer */
mach_write_to_4((byte *)crypted_buf, key_version);
int rc = encryption_scheme_encrypt(input_buf+ROW_MERGE_RESERVE_SIZE,
@@ -134,7 +134,7 @@ row_merge_decrypt_buf(
uint dstlen=0;
os_offset_t ofs = (os_offset_t)srv_sort_buf_size * (os_offset_t)offset;
- /* Read key_version from begining of the buffer */
+ /* Read key_version from beginning of the buffer */
key_version = mach_read_from_4((byte *)input_buf);
if (key_version == 0) {
diff --git a/storage/maria/ma_bitmap.c b/storage/maria/ma_bitmap.c
index 60d57b95d86..8edaa418baa 100644
--- a/storage/maria/ma_bitmap.c
+++ b/storage/maria/ma_bitmap.c
@@ -105,7 +105,7 @@
- On checkpoint
(Ie: When we do a checkpoint, we have to ensure that all bitmaps are
put on disk even if they are not in the page cache).
- - When explicitely requested (for example on backup or after recovery,
+ - When explicitly requested (for example on backup or after recovery,
to simplify things)
The flow of writing a row is that:
diff --git a/storage/maria/ma_range.c b/storage/maria/ma_range.c
index 7216480abd9..3d41cb9a37d 100644
--- a/storage/maria/ma_range.c
+++ b/storage/maria/ma_range.c
@@ -163,7 +163,7 @@ static ha_rows _ma_record_pos(MARIA_HA *info, const uchar *key_data,
operations with a comment like "Not real duplicates", whatever this
means. From the condition above we can see that 'skip_end_space' is
always false for these operations. The result is that trailing space
- counts in key comparison and hence, emtpy strings ('', string length
+ counts in key comparison and hence, empty strings ('', string length
zero, but not NULL) compare less that strings starting with control
characters and these in turn compare less than strings starting with
blanks.
diff --git a/storage/maria/maria_def.h b/storage/maria/maria_def.h
index 7337b01a981..520eeae8e16 100644
--- a/storage/maria/maria_def.h
+++ b/storage/maria/maria_def.h
@@ -175,7 +175,7 @@ typedef struct st_maria_state_info
uint changed; /* Changed since maria_chk */
/**
Birthday of the table: no record in the log before this LSN should ever
- be applied to the table. Updated when created, renamed, explicitely
+ be applied to the table. Updated when created, renamed, explicitly
repaired (REPAIR|OPTIMIZE TABLE, ALTER TABLE ENABLE KEYS, maria_chk).
*/
LSN create_rename_lsn;
diff --git a/storage/maria/unittest/sequence_storage.c b/storage/maria/unittest/sequence_storage.c
index 4563ea76c64..0bd120c43d3 100644
--- a/storage/maria/unittest/sequence_storage.c
+++ b/storage/maria/unittest/sequence_storage.c
@@ -80,7 +80,7 @@ void seq_storage_destroy(SEQ_STORAGE *seq)
/**
- @brief Starts the sequence from begining
+ @brief Starts the sequence from beginning
@param seq Reference on the sequence storage.
*/
diff --git a/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-1.7.2.js b/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-1.7.2.js
index 3774ff98613..75ce2617772 100644
--- a/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-1.7.2.js
+++ b/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-1.7.2.js
@@ -8249,7 +8249,7 @@ if ( jQuery.support.ajax ) {
xml;
// Firefox throws exceptions when accessing properties
- // of an xhr when a network error occured
+ // of an xhr when a network error occurred
// http://helpful.knobs-dials.com/index.php/Component_returned_failure_code:_0x80040111_(NS_ERROR_NOT_AVAILABLE)
try {
diff --git a/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-ui-1.8.18.custom.js b/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-ui-1.8.18.custom.js
index d4444b2bd11..a212450c20a 100644
--- a/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-ui-1.8.18.custom.js
+++ b/storage/mroonga/vendor/groonga/examples/dictionary/html/js/jquery-ui-1.8.18.custom.js
@@ -743,7 +743,7 @@ $.widget("ui.mouse", {
return this.mouseDelayMet;
},
- // These are placeholder methods, to be overriden by extending plugin
+ // These are placeholder methods, to be overridden by extending plugin
_mouseStart: function(event) {},
_mouseDrag: function(event) {},
_mouseStop: function(event) {},
diff --git a/storage/myisam/NEWS b/storage/myisam/NEWS
index bb1f141610b..a564110bffb 100644
--- a/storage/myisam/NEWS
+++ b/storage/myisam/NEWS
@@ -62,5 +62,5 @@ New features compared to NISAM:
Interface changes compared to NISAM:
- mi_create()
- - keyinfo->seg must be allocated explicitely.
+ - keyinfo->seg must be allocated explicitly.
- One must put number of key segments in keyinfo
diff --git a/storage/tokudb/PerconaFT/ft/ft-flusher.cc b/storage/tokudb/PerconaFT/ft/ft-flusher.cc
index 530947fe868..0ded678a211 100644
--- a/storage/tokudb/PerconaFT/ft/ft-flusher.cc
+++ b/storage/tokudb/PerconaFT/ft/ft-flusher.cc
@@ -496,7 +496,7 @@ handle_split_of_child(
// We never set the rightmost blocknum to be the root.
// Instead, we wait for the root to split and let promotion initialize the rightmost
- // blocknum to be the first non-root leaf node on the right extreme to recieve an insert.
+ // blocknum to be the first non-root leaf node on the right extreme to receive an insert.
BLOCKNUM rightmost_blocknum = toku_unsafe_fetch(&ft->rightmost_blocknum);
invariant(ft->h->root_blocknum.b != rightmost_blocknum.b);
if (childa->blocknum.b == rightmost_blocknum.b) {
diff --git a/storage/tokudb/PerconaFT/src/indexer-undo-do.cc b/storage/tokudb/PerconaFT/src/indexer-undo-do.cc
index b93429407eb..ca3cbdb056c 100644
--- a/storage/tokudb/PerconaFT/src/indexer-undo-do.cc
+++ b/storage/tokudb/PerconaFT/src/indexer-undo-do.cc
@@ -313,7 +313,7 @@ indexer_undo_do_provisional(DB_INDEXER *indexer, DB *hotdb, struct ule_prov_info
break;
if (outermost_xid_state != TOKUTXN_LIVE && xrindex > num_committed) {
- // if the outermost is not live, then the inner state must be retired. thats the way that the txn API works.
+ // if the outermost is not live, then the inner state must be retired. that's the way that the txn API works.
assert(this_xid_state == TOKUTXN_RETIRED);
}
diff --git a/storage/tokudb/PerconaFT/src/tests/loader-dup-test.cc b/storage/tokudb/PerconaFT/src/tests/loader-dup-test.cc
index 3f2f8d7455a..aaf77c503cc 100644
--- a/storage/tokudb/PerconaFT/src/tests/loader-dup-test.cc
+++ b/storage/tokudb/PerconaFT/src/tests/loader-dup-test.cc
@@ -51,7 +51,7 @@ int DISALLOW_PUTS=0;
int COMPRESS=0;
enum {MAGIC=311};
-bool dup_row_at_end = false; // false: duplicate at the begining. true: duplicate at the end. The duplicated row is row 0.
+bool dup_row_at_end = false; // false: duplicate at the beginning. true: duplicate at the end. The duplicated row is row 0.
int dup_row_id = 0; // 0 means to use row 1 if inserting at the end, row NUM_ROWS if inserting at the beginning. Otherwise insert the row specified here.
//
diff --git a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure
index 9dc3178ba75..2d3e2062f0d 100755
--- a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure
+++ b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure
@@ -19985,7 +19985,7 @@ fi
# Set additional flags for static/dynamic linking. The idea is that every
# program (not library) being built will use either STATIC_{CPPFLAGS,LDFLAGS}
# or DYNAMIC_{CPPFLAGS,LDFLAGS} depending on which type of linkage is
-# preferred. These preferences get overriden by use of --disable-static,
+# preferred. These preferences get overridden by use of --disable-static,
# --disable-shared, or --enable-dynamic.
#
# This is quite messy, because we want to use LZMA_API_STATIC when linking
diff --git a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure.ac b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure.ac
index d125a6936da..148f174169e 100644
--- a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure.ac
+++ b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/configure.ac
@@ -642,7 +642,7 @@ AC_SUBST([AM_CFLAGS])
# Set additional flags for static/dynamic linking. The idea is that every
# program (not library) being built will use either STATIC_{CPPFLAGS,LDFLAGS}
# or DYNAMIC_{CPPFLAGS,LDFLAGS} depending on which type of linkage is
-# preferred. These preferences get overriden by use of --disable-static,
+# preferred. These preferences get overridden by use of --disable-static,
# --disable-shared, or --enable-dynamic.
#
# This is quite messy, because we want to use LZMA_API_STATIC when linking
diff --git a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/doc/man/txt/xz.txt b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/doc/man/txt/xz.txt
index e3dacde4a11..e9b0ee5e810 100644
--- a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/doc/man/txt/xz.txt
+++ b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/doc/man/txt/xz.txt
@@ -112,7 +112,7 @@ DESCRIPTION
The absolute value of the active memory usage limit can be seen near
the bottom of the output of --long-help. The default limit can be
- overriden with --memory=limit.
+ overridden with --memory=limit.
OPTIONS
Integer suffixes and special values
diff --git a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/main.c b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/main.c
index 17fe0aa85b9..40f48645220 100644
--- a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/main.c
+++ b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/main.c
@@ -212,7 +212,7 @@ main(int argc, char **argv)
// do other message handling related initializations.
message_init(argv[0]);
- // Set hardware-dependent default values. These can be overriden
+ // Set hardware-dependent default values. These can be overridden
// on the command line, thus this must be done before parse_args().
hardware_init();
diff --git a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/xz.1 b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/xz.1
index 2fef75f43a5..ad3d8463141 100644
--- a/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/xz.1
+++ b/storage/tokudb/PerconaFT/third_party/xz-4.999.9beta/src/xz/xz.1
@@ -222,7 +222,7 @@ data has already been decompressed.
The absolute value of the active memory usage limit can be seen near
the bottom of the output of
.BR \-\-long\-help .
-The default limit can be overriden with
+The default limit can be overridden with
\fB\-\-memory=\fIlimit\fR.
.SH OPTIONS
.SS "Integer suffixes and special values"
diff --git a/storage/tokudb/tokudb_update_fun.cc b/storage/tokudb/tokudb_update_fun.cc
index 4647c91880b..19480a73bdb 100644
--- a/storage/tokudb/tokudb_update_fun.cc
+++ b/storage/tokudb/tokudb_update_fun.cc
@@ -144,7 +144,7 @@ enum {
// field type 4 see field types above
// unused 4 unused
// field null num 4 bit 31 is 1 if the field is nullible and the remaining bits contain the null bit number
-// field offset 4 for fixed fields, this is the offset from begining of the row of the field
+// field offset 4 for fixed fields, this is the offset from beginning of the row of the field
// value:
// value length 4 == N, length of the value
// value N value to add or subtract
diff --git a/storage/xtradb/dict/dict0load.cc b/storage/xtradb/dict/dict0load.cc
index d6ed8acb39e..0b1ba975eb6 100644
--- a/storage/xtradb/dict/dict0load.cc
+++ b/storage/xtradb/dict/dict0load.cc
@@ -488,7 +488,7 @@ err_len:
return("incorrect column length in SYS_FOREIGN");
}
- /* This recieves a dict_foreign_t* that points to a stack variable.
+ /* This receives a dict_foreign_t* that points to a stack variable.
So mem_heap_free(foreign->heap) is not used as elsewhere.
Since the heap used here is freed elsewhere, foreign->heap
is not assigned. */
diff --git a/storage/xtradb/row/row0merge.cc b/storage/xtradb/row/row0merge.cc
index 8d7fcd7388c..1b1d2cb56e5 100644
--- a/storage/xtradb/row/row0merge.cc
+++ b/storage/xtradb/row/row0merge.cc
@@ -97,7 +97,7 @@ row_merge_encrypt_buf(
key_version = encryption_key_get_latest_version(crypt_data->key_id);
- /* Store key_version at the begining of the input buffer */
+ /* Store key_version at the beginning of the input buffer */
mach_write_to_4((byte *)crypted_buf, key_version);
int rc = encryption_scheme_encrypt(input_buf+ROW_MERGE_RESERVE_SIZE,
@@ -134,7 +134,7 @@ row_merge_decrypt_buf(
uint dstlen=0;
os_offset_t ofs = (os_offset_t)srv_sort_buf_size * (os_offset_t)offset;
- /* Read key_version from begining of the buffer */
+ /* Read key_version from beginning of the buffer */
key_version = mach_read_from_4((byte *)input_buf);
if (key_version == 0) {
diff --git a/strings/decimal.c b/strings/decimal.c
index 74d456c9c9f..e64f7634a45 100644
--- a/strings/decimal.c
+++ b/strings/decimal.c
@@ -457,7 +457,7 @@ static void digits_bounds(decimal_t *from, int *start_result, int *end_result)
dec1 *end= from->buf + ROUND_UP(from->intg) + ROUND_UP(from->frac);
dec1 *buf_end= end - 1;
- /* find non-zero digit from number begining */
+ /* find non-zero digit from number beginning */
while (buf_beg < end && *buf_beg == 0)
buf_beg++;
@@ -468,7 +468,7 @@ static void digits_bounds(decimal_t *from, int *start_result, int *end_result)
return;
}
- /* find non-zero decimal digit from number begining */
+ /* find non-zero decimal digit from number beginning */
if (buf_beg == from->buf && from->intg)
{
start= DIG_PER_DEC1 - (i= ((from->intg-1) % DIG_PER_DEC1 + 1));
diff --git a/strings/string.doc b/strings/string.doc
index fcd020b8c60..3e5b607347a 100644
--- a/strings/string.doc
+++ b/strings/string.doc
@@ -41,7 +41,7 @@ Speciella användbara nya string-rutiner:
backwards from pos from. pat is not a regex(3) pattern, it is a literal
string which must be matched exactly.
The result 0 if the pattern was not found else it is the start char of
- the pattern counted from the begining of the string.
+ the pattern counted from the beginning of the string.
strappend(dest, len, fill) appends fill-characters to a string so that
the result length == len. If the string is longer than len it's
diff --git a/support-files/mysql.server.sh b/support-files/mysql.server.sh
index e5cdbfd3ce8..d09cefef50d 100644
--- a/support-files/mysql.server.sh
+++ b/support-files/mysql.server.sh
@@ -47,8 +47,8 @@ basedir=
datadir=
# Default value, in seconds, afterwhich the script should timeout waiting
-# for server start.
-# Value here is overriden by value in my.cnf.
+# for server start.
+# Value here is overridden by value in my.cnf.
# 0 means don't wait at all
# Negative numbers mean to wait indefinitely
service_startup_timeout=900
@@ -379,9 +379,9 @@ case "$mode" in
;;
'status')
# First, check to see if pid file exists
- if test -s "$mysqld_pid_file_path" ; then
+ if test -s "$mysqld_pid_file_path" ; then
read mysqld_pid < "$mysqld_pid_file_path"
- if kill -0 $mysqld_pid 2>/dev/null ; then
+ if kill -0 $mysqld_pid 2>/dev/null ; then
log_success_msg "MySQL running ($mysqld_pid)"
exit 0
else
@@ -397,11 +397,11 @@ case "$mode" in
if test $pid_count -gt 1 ; then
log_failure_msg "Multiple MySQL running but PID file could not be found ($mysqld_pid)"
exit 5
- elif test -z $mysqld_pid ; then
- if test -f "$lock_file_path" ; then
+ elif test -z $mysqld_pid ; then
+ if test -f "$lock_file_path" ; then
log_failure_msg "MySQL is not running, but lock file ($lock_file_path) exists"
exit 2
- fi
+ fi
log_failure_msg "MySQL is not running"
exit 3
else
diff --git a/client/mysqltest.cc b/client/mysqltest.cc
index afb746cd62f..d5ebf11349a 100644
--- a/client/mysqltest.cc
+++ b/client/mysqltest.cc
@@ -6526,7 +6526,7 @@ int read_line(char *buf, int size)
start_lineno));
}
/* Skip all space at begining of line */
skip_char= 1;
}
else if (end_of_query(c))
@@ -6538,10 +6538,10 @@ int read_line(char *buf, int size)
}
else if (c == '}')
{
/* A "}" need to be by itself in the begining of a line to terminate */
*p++= c;
*p= 0;
- DBUG_PRINT("exit", ("Found '}' in begining of a line at line: %d",
+ DBUG_PRINT("exit", ("Found '}' in beginning of a line at line: %d",
cur_file->lineno));
DBUG_RETURN(0);
}
@@ -6526,7 +6526,7 @@ int read_line(char *buf, int size)
start_lineno));
}
- /* Skip all space at begining of line */
+ /* Skip all space at beginning of line */
skip_char= 1;
}
@@ -6538,10 +6538,10 @@ int read_line(char *buf, int size)
else if (c == '}')
{
- /* A "}" need to be by itself in the begining of a line to terminate */
+ /* A "}" need to be by itself in the beginning of a line to terminate */
*p++= c;
*p= 0;
diff --git a/sql/sql_cache.cc b/sql/sql_cache.cc
index 6d1a8efaf22..06c5f992939 100644
--- a/sql/sql_cache.cc
+++ b/sql/sql_cache.cc
@@ -2356,7 +2356,7 @@ void Query_cache::invalidate(THD *thd, char *db)
}
/*
The used tables are linked in a circular list;
- loop until we return to the begining.
+ loop until we return to the beginning.
*/
} while (table_block != tables_blocks);
/*
@@ -3297,7 +3297,7 @@ Query_cache::invalidate_query_block_list(THD *thd,
}
/*
- Register given table list begining with given position in tables table of
+ Register given table list beginning with given position in tables table of
block
SYNOPSIS
@@ -4340,7 +4340,7 @@ my_bool Query_cache::move_by_type(uchar **border,
{
Query_cache_block_table *block_table = new_block->table(j);
// use aligment from begining of table if 'next' is in same block
if ((beg_of_table_table <= block_table->next) &&
(block_table->next < end_of_table_table))
((Query_cache_block_table *)(beg_of_new_table_table +
@@ -4350,7 +4350,7 @@ my_bool Query_cache::move_by_type(uchar **border,
else
block_table->next->prev= block_table;
// use aligment from begining of table if 'prev' is in same block
if ((beg_of_table_table <= block_table->prev) &&
(block_table->prev < end_of_table_table))
((Query_cache_block_table *)(beg_of_new_table_table +
@@ -4847,7 +4847,7 @@ my_bool Query_cache::check_integrity(bool locked)
if (((uchar*)block) + block->length != ((uchar*)block->pnext))
{
DBUG_PRINT("error",
- ("block 0x%lx, type %u, ended at 0x%lx, but next block begining at 0x%lx",
+ ("block 0x%lx, type %u, ended at 0x%lx, but next block beginning at 0x%lx",
(ulong) block, (uint) block->type,
(ulong) (((uchar*)block) + block->length),
(ulong) ((uchar*)block->pnext)));
@@ -4340,7 +4340,7 @@ my_bool Query_cache::move_by_type(uchar **border,
{
Query_cache_block_table *block_table = new_block->table(j);
- // use aligment from begining of table if 'next' is in same block
+ // use aligment from beginning of table if 'next' is in same block
if ((beg_of_table_table <= block_table->next) &&
(block_table->next < end_of_table_table))
@@ -4350,7 +4350,7 @@ my_bool Query_cache::move_by_type(uchar **border,
else
block_table->next->prev= block_table;
- // use aligment from begining of table if 'prev' is in same block
+ // use aligment from beginning of table if 'prev' is in same block
if ((beg_of_table_table <= block_table->prev) &&
(block_table->prev < end_of_table_table))